summaryrefslogtreecommitdiff
path: root/indra/newview/llpanelclassified.h
diff options
context:
space:
mode:
Diffstat (limited to 'indra/newview/llpanelclassified.h')
-rw-r--r--indra/newview/llpanelclassified.h2
1 files changed, 1 insertions, 1 deletions
diff --git a/indra/newview/llpanelclassified.h b/indra/newview/llpanelclassified.h
index 68a5a33321..417eddf460 100644
--- a/indra/newview/llpanelclassified.h
+++ b/indra/newview/llpanelclassified.h
@@ -120,7 +120,7 @@ protected:
static void focusReceived(LLFocusableElement* ctrl, void* data);
static void onCommitAny(LLUICtrl* ctrl, void* data);
- void constrainAccessCombo(); // Force AO and PG regions to proper classified access
+ void setDefaultAccessCombo(); // Default AO and PG regions to proper classified access
BOOL checkDirty(); // Update and return mDirty